@@ -80,7 +80,7 @@ def gen_model_input(train_set,user_profile,seq_max_len):
     train_hist_len = np.array([line[4] for line in train_set])
 
     train_seq_pad = pad_sequences(train_seq, maxlen=seq_max_len, padding='post', truncating='post', value=0)
-    train_model_input = {"user_id": train_uid, "movie_id": train_iid, "hist_movie_id": train_seq_pad,
+    train_model_input = {"user_idx": train_uid, "movie_idx": train_iid, "hist_movie_idx": train_seq_pad,
                          "hist_len": train_hist_len}
 
     #for key in ["gender", "age", "occupation", "zip"]:
